Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(374)

Unified Diff: third_party/WebKit/public/web/WebSurroundingText.h

Issue 2199523002: Convert WebRange to be a simple pair of numbers. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Forgot the exports. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/public/web/WebRange.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebSurroundingText.h
diff --git a/third_party/WebKit/public/web/WebSurroundingText.h b/third_party/WebKit/public/web/WebSurroundingText.h
index e5315c63efe7246bbeabf15495f47f4ae1f51b0b..ec456d64f9ebb2730beb1dc7321519ea8f35797f 100644
--- a/third_party/WebKit/public/web/WebSurroundingText.h
+++ b/third_party/WebKit/public/web/WebSurroundingText.h
@@ -35,6 +35,7 @@ namespace blink {
class SurroundingText;
class WebNode;
class WebRange;
+class WebLocalFrame;
struct WebPoint;
// WebSurroundingText is a Blink API that gives access to the SurroundingText
@@ -50,11 +51,10 @@ public:
// position relative to a provided node.
// The maximum length of the contents retrieved is defined by maxLength.
BLINK_EXPORT void initialize(const WebNode&, const WebPoint&, size_t maxLength);
-
- // Initializes the object to get the text surrounding a given range.
+ // Initializes the object with the current selection in a given frame.
// The maximum length of the contents retrieved is defined by maxLength.
// It does not include the text inside the range.
- BLINK_EXPORT void initialize(const WebRange&, size_t maxLength);
+ BLINK_EXPORT void initializeFromCurrentSelection(WebLocalFrame*, size_t maxLength);
// Surrounding text content retrieved.
BLINK_EXPORT WebString textContent() const;
« no previous file with comments | « third_party/WebKit/public/web/WebRange.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698